@@ -16,7 +16,7 @@ def parse_options(args_):
     parser.add_argument('--no-error', action='store_true', default=False, help='if turned on the program won\'t raise errors, just print the fails. This should be turned off when using github actions')
     parser.add_argument('--one-error', action='store_true', default=False, help='if turned on the program will only raise one error after all tests were tested')
 
-    return parser.parse_args(args_)
+    return parser.parse_args(os.cwd() + '/' + args_)
 
 def import_files(file_):
     file_ = file_.replace('//', '.').replace('/', '.').replace('\\', '.').replace('.py', '')
